#!/bin/bash

#-------------------------------------------------------------------------------
#
# Batch options for SLURM (Simple Linux Utility for Resource Management)
# =======================
#
#SBATCH --ntasks=64
#SBATCH --time=72:00:00
#SBATCH --job-name=job1
#SBATCH --account=2370156
#
#  -t<time>, --time=<time>            : walltime in minutes, minutes:seconds,
#                                       hours:minutes:seconds, days-hours,
#                                       days-hours:minutes, or
#                                       days-hours:minutes:seconds
#  -N, --nodes=<minnodes[-maxnodes]>  : number of allocated nodes
#  --ntasks=24, -n24                  : number of total tasks
#  --ntasks-per-node=<ntasks>         : number of tasks per node
#  --ntasks-per-socket=<ntasks>       : number of tasks per socket
#  --ntasks-per-core=<ntasks>         : number of tasks per core
#  --cpus-per-task=<nthreads>         : number of threads per task
#  --cpu-bind=cores, sockets          : bind CPUs to cores or sockets
#  --mem-bind=local
#  --qos=<qos>                        : request given quality of service
#                                       (for example "debug")
#  --contiguous                       : use contiguous nodes for minimal latency
#  --exclusive                        : do not share nodes with other jobs
#  --switches=<count>[@max-delay]     : try to run on no more than count
#                                       switches (for better performance)
#  --partition=<name>, -p<name>       : partition (queue) (run "sinfo -s"
#                                       for list of partitions)
#  --reservation=<name>               : allocate resources from reservation
#  -o<pattern>, --output=<pattern>    : output file name pattern (%j  - template for jobid)
#  -e<pattern>, --error=<pattern>     : error file name pattern  (%j  - template for jobid)
#  -J<jobname>, --job-name=<jobname>  : job name
#
#-------------------------------------------------------------------------------

STUDY=/scratch/ws/1/beck_rf-pressure_drop/pressure_control
CASE=$STUDY/ImposedPOutlet
PARAM=run.xml

if [ X_$SLURM_NPROCS == X_ ]; then SLURM_NPROCS=1; fi

# Change to submission directory
if test -n "$SLURM_SUBMIT_DIR" ; then cd $SLURM_SUBMIT_DIR ; fi

export PATH=/home/beck_rf/Software/Code_Saturne/5.0.9/code_saturne-5.0.9/bin:$PATH

# Run command:
\code_saturne run --param $PARAM -n $SLURM_NPROCS
